==> myfaces-core-assembly-1.2.12-src.zip: org/apache/myfaces/config/annotation/NoAnnotationLifecyleProvider.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.myfaces.config.annotation;

import org.apache.myfaces.shared_impl.util.ClassUtils;

import java.lang.reflect.InvocationTargetException;

public class NoAnnotationLifecyleProvider implements LifecycleProvider2
{


    public void destroyInstance(Object o) throws IllegalAccessException, InvocationTargetException
    {

    }

    public Object newInstance(String className) throws InstantiationException, IllegalAccessException, InvocationTargetException, ClassNotFoundException
    {
        Class clazz = ClassUtils.classForName(className);
        return clazz.newInstance();
    }

    public void postConstruct(Object o) throws IllegalAccessException,
            InvocationTargetException
    {
        // No op
    }

}

==> myfaces-core-assembly-2.3.11-src.zip: org/apache/myfaces/config/annotation/NoAnnotationLifecyleProvider.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.myfaces.config.annotation;

import org.apache.myfaces.shared.util.ClassUtils;

import java.lang.reflect.InvocationTargetException;

public class NoAnnotationLifecyleProvider implements LifecycleProvider2
{


    public void destroyInstance(Object o) throws IllegalAccessException, InvocationTargetException
    {

    }

    public Object newInstance(String className)
            throws InstantiationException, IllegalAccessException, InvocationTargetException, ClassNotFoundException
    {
        return ClassUtils.classForName(className).newInstance();
    }
    public void postConstruct(Object o) throws IllegalAccessException,
            InvocationTargetException
    {
        // No op
    }

}
